@@ -31,9 +31,9 @@ import wsmeext.pecan as wsme_pecan
 from panko.api.controllers.v2 import base
 from panko.api.controllers.v2 import utils as v2_utils
 from panko.api import rbac
+from panko.i18n import _
 from panko import storage
 from panko.storage import models as event_models
-from panko.i18n import _, _LE
 
 LOG = log.getLogger(__name__)
 
@@ -62,6 +62,12 @@ class EventQuery(base.Query):
     type = wsme.wsattr(wtypes.text, default='string')
     "the type of the trait filter, defaults to string"
 
+    field = wsme.wsattr(wtypes.text)
+    '''
+    Name of the field to filter on. Can be either a trait name or field of an
+    event. Use start_timestamp/end_timestamp to filter on `generated` field
+    '''
+
     def __repr__(self):
         # for logging calls
         return '<EventQuery %r %s %r %s>' % (self.field,
@@ -316,8 +322,8 @@ class EventsController(rest.RestController):
             raise base.EntityNotFound(_("Event"), message_id)
 
         if len(events) > 1:
-            LOG.error(_LE("More than one event with "
-                          "id %s returned from storage driver") % message_id)
+            LOG.error(("More than one event with "
+                       "id %s returned from storage driver"), message_id)
 
         event = events[0]
 
