@@ -26,4 +26,11 @@ STORAGE_OPTS = [
                default=10,
                deprecated_group='database',
                help='Interval (in seconds) between retries of connection.'),
+    cfg.BoolOpt('es_ssl_enabled',
+                default=False,
+                help="Enable HTTPS connection in the Elasticsearch "
+                     "connection"),
+    cfg.StrOpt('es_index_name',
+               default='events',
+               help='The name of the index in Elasticsearch'),
 ]
