@@ -23,11 +23,11 @@ from oslo_db.sqlalchemy import utils as oslo_sql_utils
 from oslo_log import log
 from oslo_utils import timeutils
 import sqlalchemy as sa
+from sqlalchemy.engine import url as sqlalchemy_url
 
+from panko import storage
 from panko.storage import base
 from panko.storage import models as api_models
-from panko.i18n import _LE, _LI
-from panko import storage
 from panko.storage.sqlalchemy import models
 from panko import utils
 
@@ -129,12 +129,22 @@ class Connection(base.Connection):
         # to retry making the db connection retried max_retries ^ 2 times
         # in failure case and db reconnection has already been implemented
         # in storage.__init__.get_connection_from_config function
-        options = dict(conf)
+        options = dict(conf.database.items())
         options['max_retries'] = 0
         # oslo.db doesn't support options defined by Panko
         for opt in storage.OPTS:
             options.pop(opt.name, None)
-        self._engine_facade = db_session.EngineFacade(url, **options)
+        self._engine_facade = db_session.EngineFacade(self.dress_url(url),
+                                                      **options)
+
+    @staticmethod
+    def dress_url(url):
+        # If no explicit driver has been set, we default to pymysql
+        if url.startswith("mysql://"):
+            url = sqlalchemy_url.make_url(url)
+            url.drivername = "mysql+pymysql"
+            return str(url)
+        return url
 
     def upgrade(self):
         engine = self._engine_facade.get_engine()
@@ -196,11 +206,11 @@ class Connection(base.Connection):
                             session.execute(model.__table__.insert(),
                                             trait_map[dtype])
             except dbexc.DBDuplicateEntry as e:
-                LOG.info(_LI("Duplicate event detected, skipping it: %s") % e)
+                LOG.info("Duplicate event detected, skipping it: %s", e)
             except KeyError as e:
-                LOG.exception(_LE('Failed to record event: %s') % e)
+                LOG.exception('Failed to record event: %s', e)
             except Exception as e:
-                LOG.exception(_LE('Failed to record event: %s') % e)
+                LOG.exception('Failed to record event: %s', e)
                 error = e
         if error:
             raise error
@@ -459,4 +469,4 @@ class Connection(base.Connection):
             (session.query(models.EventType)
              .filter(~models.EventType.events.any())
              .delete(synchronize_session="fetch"))
-            LOG.info(_LI("%d events are removed from database"), event_rows)
+            LOG.info("%d events are removed from database", event_rows)
